@@ -769,7 +769,7 @@ if (! window._OQAjaxQueryLoaded)
           .attr('data-uid', updated_uid)
           .text('record '+updated_uid+' saved')
           .insertAfter($f.children('.OQinfo'));
-        $f.find('tr[data-uid='+updated_uid+']').addClass('OQupdatedRow');
+        $f.find('tr[data-uid="'+updated_uid+'"]').addClass('OQupdatedRow');
       });
     }
   };
